AuthRepository class

Constructors

AuthRepository(FirebaseAuth _auth)

Properties

authState Stream<User?>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerWithEmail({required String email, required String password, required AuthSuccessCallback onSuccess, required AuthFailureCallback onFailure}) Future<void>
signInWithEmail({required String email, required String password, required AuthSuccessCallback onSuccess, required AuthFailureCallback onFailure}) Future<void>
signOut() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited